pub struct Bush<T: Integer> {
pub prime_base: T,
pub strength: T,
pub dimensions: T,
}Expand description
Generate an orthogonal array with any prime base and a strength between 2 and p + 1
The Bush construction technique, as described by Art Owen in his currently unpublished Monte Carlo textbook. In Chapter 10.4, he describes the Bush construction technique.
Note that using this struct directly does not check any parameters. You should only use this if you are certain that your parameters are valid, otherwise the resulting orthogonal array will be invalid.
Fields
prime_base: TThe strength of the orthogonal array. It must be a prime number.
strength: TThe desired strength of the orthogonal array. It must be greater than or equal to 2. It must also be
dimensions: TThe dimensionality of the orthogonal array